Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type M ¶
type M struct {
*base.MDC
vecty.Core
Root vecty.MarkupOrChild `vecty:"prop"`
// Open is the visible state of the menu component.
Open bool `vecty:"prop"`
// QuickOpen controls whether the menu should open and close without
// animation. False uses animation, true does not.
QuickOpen bool `vecty:"prop"`
// List is a HTMLUListElement containing the menu's items.
List vecty.ComponentOrHTML `vecty:"prop"`
// Set AnchorElement to embed the menu component inside an HTMLElement from
// which the element will be anchored.
AnchorElement vecty.ComponentOrHTML `vecty:"prop"`
// Define OnSelect to handle "MDCMenu:selected" events. item is the
// menu item that was selected.
OnSelect func(index int, item vecty.ComponentOrHTML, e *vecty.Event) `vecty:"prop"`
// Define OnCancel to handle "MDCMenu:selected" events. item is the
// menu item that was selected.
OnCancel func(e *vecty.Event) `vecty:"prop"`
// contains filtered or unexported fields
}
M is a vecty-material menu component.
func (*M) Render ¶
func (c *M) Render() vecty.ComponentOrHTML
Render implements the vecty.Component interface.
Click to show internal directories.
Click to hide internal directories.