snackbar

package
v0.0.0-...-1bbb42b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 17, 2021 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type S

type S struct {
	*base.MDC
	vecty.Core
	Root    vecty.MarkupOrChild   `vecty:"prop"`
	Label   vecty.ComponentOrHTML `vecty:"prop"`
	Buttons []*button.B           `vecty:"prop"`
}

S is a vecty-material snackbar component.

func (*S) Apply

func (c *S) Apply(h *vecty.HTML)

func (*S) Open

func (c *S) Open() error

Open displays the snackbar. If the configuration is invalid an error message will be returned and the snackbar will not be shown. For information on config requirements look at documentation for S.

func (*S) Render

func (c *S) Render() vecty.ComponentOrHTML

Render implements the vecty.Component interface.

Jump to