Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type S ¶
type S struct {
*base.MDC
vecty.Core
Root vecty.MarkupOrChild `vecty:"prop"`
Label vecty.ComponentOrHTML `vecty:"prop"`
Buttons []*button.B `vecty:"prop"`
}
S is a vecty-material snackbar component.
func (*S) Open ¶
Open displays the snackbar. If the configuration is invalid an error message will be returned and the snackbar will not be shown. For information on config requirements look at documentation for S.
func (*S) Render ¶
func (c *S) Render() vecty.ComponentOrHTML
Render implements the vecty.Component interface.
Click to show internal directories.
Click to hide internal directories.